@@ -5,9 +5,10 @@
 //!
 //!
 //! [babylon/util/identifier.js]:https://github.com/babel/babel/blob/master/packages/babylon/src/util/identifier.js
-use super::{input::Input, Char, LexResult, Lexer};
+use super::{comments_buffer::BufferedComment, input::Input, Char, LexResult, Lexer};
 use crate::{
     error::{Error, SyntaxError},
+    lexer::comments_buffer::BufferedCommentKind,
     Tokens,
 };
 use std::char;
@@ -230,26 +231,22 @@ impl<'a, I: Input> Lexer<'a, I> {
             }
         }
 
-        if !self.ctx.dont_store_comments {
-            if let Some(ref comments) = self.comments {
-                let s = self.input.slice(slice_start, end);
-                let cmt = Comment {
-                    kind: CommentKind::Line,
-                    span: Span::new(start, end, SyntaxContext::empty()),
-                    text: s.into(),
-                };
+        if let Some(comments) = self.comments_buffer.as_mut() {
+            let s = self.input.slice(slice_start, end);
+            let cmt = Comment {
+                kind: CommentKind::Line,
+                span: Span::new(start, end, SyntaxContext::empty()),
+                text: s.into(),
+            };
 
-                if start >= *self.last_comment_pos.borrow() {
-                    *self.last_comment_pos.borrow_mut() = end;
-
-                    if is_for_next {
-                        if let Some(buf) = &self.leading_comments_buffer {
-                            buf.borrow_mut().push(cmt);
-                        }
-                    } else {
-                        comments.add_trailing(self.state.prev_hi, cmt);
-                    }
-                }
+            if is_for_next {
+                comments.push_pending_leading(cmt);
+            } else {
+                comments.push(BufferedComment {
+                    kind: BufferedCommentKind::Trailing,
+                    pos: self.state.prev_hi,
+                    comment: cmt,
+                });
             }
         }
 
@@ -284,28 +281,24 @@ impl<'a, I: Input> Lexer<'a, I> {
 
                 let end = self.cur_pos();
 
-                if !self.ctx.dont_store_comments {
-                    if let Some(ref comments) = self.comments {
-                        let src = self.input.slice(slice_start, end);
-                        let s = &src[..src.len() - 2];
-                        let cmt = Comment {
-                            kind: CommentKind::Block,
-                            span: Span::new(start, end, SyntaxContext::empty()),
-                            text: s.into(),
-                        };
+                if let Some(comments) = self.comments_buffer.as_mut() {
+                    let src = self.input.slice(slice_start, end);
+                    let s = &src[..src.len() - 2];
+                    let cmt = Comment {
+                        kind: CommentKind::Block,
+                        span: Span::new(start, end, SyntaxContext::empty()),
+                        text: s.into(),
+                    };
 
-                        let _ = self.input.peek();
-                        if start >= *self.last_comment_pos.borrow() {
-                            *self.last_comment_pos.borrow_mut() = end;
-
-                            if is_for_next {
-                                if let Some(buf) = &self.leading_comments_buffer {
-                                    buf.borrow_mut().push(cmt);
-                                }
-                            } else {
-                                comments.add_trailing(self.state.prev_hi, cmt);
-                            }
-                        }
+                    let _ = self.input.peek();
+                    if is_for_next {
+                        comments.push_pending_leading(cmt);
+                    } else {
+                        comments.push(BufferedComment {
+                            kind: BufferedCommentKind::Trailing,
+                            pos: self.state.prev_hi,
+                            comment: cmt,
+                        });
                     }
                 }
 
